"C:\Program Files (x86)\LibreOffice 3.4\program\soffice.exe" -nologo -norecover -norestore -invisible -headless -nocrashreport -nofirststartwizard -nodefault -accept="socket,host=127.0.0.1,port=8997;urp;"
